@@ -29,7 +29,7 @@ class MainModel(QtCore.QObject):
     """Repository status model"""
 
     # Refactor: split this class apart into separate DiffModel, CommitMessageModel,
-    # StatusModel, and an DiffEditorState.
+    # StatusModel, and a DiffEditorState.
 
     # Signals
     about_to_update = Signal()
@@ -613,7 +613,7 @@ def no_color(kwargs):
 
 def autodetect_proxy(context, kwargs):
     """Detect proxy settings when running on Gnome and KDE"""
-    # kwargs can refer to persistant global state so we purge it.
+    # kwargs can refer to persistent global state so we purge it.
     # Callers should not expect their _add_env to persist.
     kwargs.pop('_add_env', None)
     enabled = prefs.autodetect_proxy(context)
@@ -716,10 +716,22 @@ def autodetect_proxy_kde(kreadconfig, scheme):
         '--group',
         'Proxy Settings',
         '--key',
-        f'{scheme}Proxy',
+        'ProxyType',
     ]
     status, out, err = core.run_command(cmd)
-    if status == 0:
-        proxy = out.strip()
-        return proxy
+    if status == 0 and out.strip() == '1':
+        cmd = [
+            kreadconfig,
+            '--file',
+            'kioslaverc',
+            '--group',
+            'Proxy Settings',
+            '--key',
+            f'{scheme}Proxy',
+        ]
+        status, out, err = core.run_command(cmd)
+        if status == 0:
+            proxy = out.strip().replace(' ', ':')
+            return proxy
+        return None
     return None
