@@ -163,12 +163,8 @@ scissors
         self.merge_diffstat = qtutils.checkbox(checked=True)
         self.display_untracked = qtutils.checkbox(checked=True)
         self.show_path = qtutils.checkbox(checked=True)
-
-        self.refresh_on_focus = qtutils.checkbox(checked=False)
-        tooltip = N_(
-            'Refresh repository state whenever the window is focused or un-minimized'
-        )
-        self.refresh_on_focus.setToolTip(tooltip)
+        self.update_index = qtutils.checkbox(checked=True)
+        self.http_proxy = QtWidgets.QLineEdit()
 
         tooltip = N_(
             'Enable file system change monitoring using '
@@ -184,44 +180,41 @@ scissors
         )
         self.logdate.setToolTip(tooltip)
 
-        tooltip = N_('Detect conflict markers in unmerged files')
-        self.check_conflicts = qtutils.checkbox(checked=True, tooltip=tooltip)
-
         tooltip = N_('Use gravatar.com to lookup icons for author emails')
         self.enable_gravatar = qtutils.checkbox(checked=True, tooltip=tooltip)
 
-        tooltip = N_('Prevent "Stage" from staging all files when nothing is selected')
-        self.safe_mode = qtutils.checkbox(checked=False, tooltip=tooltip)
-
         tooltip = N_('Enable path autocompletion in tools')
         self.autocomplete_paths = qtutils.checkbox(checked=True, tooltip=tooltip)
 
-        tooltip = N_('Check whether a commit has been published when amending')
-        self.check_published_commits = qtutils.checkbox(checked=True, tooltip=tooltip)
+        self.proxy_spacer = QtWidgets.QLabel()
+        tooltip = N_('Enable detection and configuration of HTTP proxy settings')
+        self.autodetect_proxy = qtutils.checkbox(checked=True, tooltip=tooltip)
 
-        self.add_row(N_('User Name'), self.name)
-        self.add_row(N_('Email Address'), self.email)
+        self.add_row(N_('Name'), self.name)
+        self.add_row(N_('Email'), self.email)
         self.add_row(N_('Patches Directory'), self.patches_directory)
         self.add_row(N_('Log Date Format'), self.logdate)
         self.add_row(N_('Commit Message Cleanup'), self.commit_cleanup)
         self.add_row(N_('Merge Verbosity'), self.merge_verbosity)
         self.add_row(N_('Number of Diff Context Lines'), self.diff_context)
-        self.add_row(N_('Refresh on Focus'), self.refresh_on_focus)
-        self.add_row(N_('Enable File System Change Monitoring'), self.inotify)
         self.add_row(N_('Summarize Merge Commits'), self.merge_summary)
+        self.add_row(N_('Enable Filesystem Monitoring'), self.inotify)
         self.add_row(
             N_('Automatically Load Commit Message Template'), self.autotemplate
         )
         self.add_row(N_('Show Full Paths in the Window Title'), self.show_path)
         self.add_row(N_('Show Diffstat After Merge'), self.merge_diffstat)
         self.add_row(N_('Display Untracked Files'), self.display_untracked)
-        self.add_row(N_('Detect Conflict Markers'), self.check_conflicts)
         self.add_row(N_('Enable Gravatar Icons'), self.enable_gravatar)
-        self.add_row(N_('Safe Mode'), self.safe_mode)
         self.add_row(N_('Autocomplete Paths'), self.autocomplete_paths)
+        self.add_row(N_('Update Index on Startup'), self.update_index)
+
+        self.add_row('', self.proxy_spacer)
         self.add_row(
-            N_('Check Published Commits when Amending'), self.check_published_commits
+            N_('Automatically Detect and Configure Proxy Settings'),
+            self.autodetect_proxy,
         )
+        self.add_row(N_('HTTP Proxy URL'), self.http_proxy)
 
         self.set_config({
             prefs.AUTOTEMPLATE: (self.autotemplate, Defaults.autotemplate),
@@ -229,10 +222,9 @@ scissors
                 self.autocomplete_paths,
                 Defaults.autocomplete_paths,
             ),
-            prefs.CHECK_CONFLICTS: (self.check_conflicts, Defaults.check_conflicts),
-            prefs.CHECK_PUBLISHED_COMMITS: (
-                self.check_published_commits,
-                Defaults.check_published_commits,
+            prefs.AUTODETECT_PROXY: (
+                self.autodetect_proxy,
+                Defaults.autodetect_proxy,
             ),
             prefs.COMMIT_CLEANUP: (self.commit_cleanup, Defaults.commit_cleanup),
             prefs.DIFFCONTEXT: (self.diff_context, Defaults.diff_context),
@@ -241,6 +233,7 @@ scissors
                 Defaults.display_untracked,
             ),
             prefs.ENABLE_GRAVATAR: (self.enable_gravatar, Defaults.enable_gravatar),
+            prefs.HTTP_PROXY: (self.http_proxy, Defaults.http_proxy),
             prefs.INOTIFY: (self.inotify, Defaults.inotify),
             prefs.LOGDATE: (self.logdate, Defaults.logdate),
             prefs.MERGE_DIFFSTAT: (self.merge_diffstat, Defaults.merge_diffstat),
@@ -250,11 +243,10 @@ scissors
                 self.patches_directory,
                 Defaults.patches_directory,
             ),
-            prefs.REFRESH_ON_FOCUS: (self.refresh_on_focus, Defaults.refresh_on_focus),
-            prefs.SAFE_MODE: (self.safe_mode, Defaults.safe_mode),
             prefs.SHOW_PATH: (self.show_path, Defaults.show_path),
             prefs.USER_NAME: (self.name, ''),
             prefs.USER_EMAIL: (self.email, ''),
+            prefs.UPDATE_INDEX: (self.update_index, Defaults.update_index),
         })
 
 
@@ -264,7 +256,6 @@ class SettingsFormWidget(FormWidget):
 
         self.fixed_font = QtWidgets.QFontComboBox()
         self.font_size = standard.SpinBox(value=12, mini=6, maxi=192)
-
         self.maxrecent = standard.SpinBox(maxi=99)
         self.tabwidth = standard.SpinBox(maxi=42)
         self.textwidth = standard.SpinBox(maxi=150)
@@ -281,8 +272,20 @@ class SettingsFormWidget(FormWidget):
         self.sort_bookmarks = qtutils.checkbox()
         self.save_window_settings = qtutils.checkbox()
         self.check_spelling = qtutils.checkbox()
-        self.expandtab = qtutils.checkbox()
+        tooltip = N_('Detect conflict markers in unmerged files')
+        self.check_conflicts = qtutils.checkbox(checked=True, tooltip=tooltip)
+        self.expandtab = qtutils.checkbox(tooltip=N_('Insert tabs instead of spaces'))
+        tooltip = N_('Prevent "Stage" from staging all files when nothing is selected')
+        self.safe_mode = qtutils.checkbox(checked=False, tooltip=tooltip)
+        tooltip = N_('Check whether a commit has been published when amending')
+        self.check_published_commits = qtutils.checkbox(checked=True, tooltip=tooltip)
+        tooltip = N_(
+            'Refresh repository state whenever the window is focused or un-minimized'
+        )
+        self.refresh_on_focus = qtutils.checkbox(checked=False, tooltip=tooltip)
         self.resize_browser_columns = qtutils.checkbox(checked=False)
+        tooltip = N_('Emit notifications when commits are pushed.')
+        self.notifyonpush = qtutils.checkbox(checked=False, tooltip=tooltip)
 
         self.add_row(N_('Fixed-Width Font'), self.fixed_font)
         self.add_row(N_('Font Size'), self.font_size)
@@ -293,15 +296,22 @@ class SettingsFormWidget(FormWidget):
         self.add_row(N_('Blame Viewer'), self.blameviewer)
         self.add_row(N_('Diff Tool'), self.difftool)
         self.add_row(N_('Merge Tool'), self.mergetool)
-        self.add_row(N_('Recent repository count'), self.maxrecent)
+        self.add_row(N_('Recent Repository Count'), self.maxrecent)
         self.add_row(N_('Auto-Wrap Lines'), self.linebreak)
-        self.add_row(N_('Insert spaces instead of tabs'), self.expandtab)
-        self.add_row(N_('Sort bookmarks alphabetically'), self.sort_bookmarks)
+        self.add_row(N_('Insert Spaces Instead of Tabs'), self.expandtab)
+        self.add_row(
+            N_('Check Published Commits when Amending'), self.check_published_commits
+        )
+        self.add_row(N_('Sort Bookmarks Alphabetically'), self.sort_bookmarks)
+        self.add_row(N_('Safe Mode'), self.safe_mode)
+        self.add_row(N_('Detect Conflict Markers'), self.check_conflicts)
         self.add_row(N_('Keep *.orig Merge Backups'), self.keep_merge_backups)
         self.add_row(N_('Save GUI Settings'), self.save_window_settings)
+        self.add_row(N_('Refresh on Focus'), self.refresh_on_focus)
         self.add_row(N_('Resize File Browser columns'), self.resize_browser_columns)
-        self.add_row(N_('Check spelling'), self.check_spelling)
-        self.add_row(N_('Ctrl+MouseWheel to Zoom'), self.mouse_zoom)
+        self.add_row(N_('Check Spelling'), self.check_spelling)
+        self.add_row(N_('Ctrl + MouseWheel to Zoom'), self.mouse_zoom)
+        self.add_row(N_('Notify on Push'), self.notifyonpush)
 
         self.set_config({
             prefs.SAVEWINDOWSETTINGS: (
@@ -321,17 +331,25 @@ class SettingsFormWidget(FormWidget):
                 prefs.default_history_browser(),
             ),
             prefs.BLAME_VIEWER: (self.blameviewer, Defaults.blame_viewer),
+            prefs.CHECK_CONFLICTS: (self.check_conflicts, Defaults.check_conflicts),
+            prefs.CHECK_PUBLISHED_COMMITS: (
+                self.check_published_commits,
+                Defaults.check_published_commits,
+            ),
             prefs.MERGE_KEEPBACKUP: (
                 self.keep_merge_backups,
                 Defaults.merge_keep_backup,
             ),
             prefs.MERGETOOL: (self.mergetool, Defaults.mergetool),
+            prefs.REFRESH_ON_FOCUS: (self.refresh_on_focus, Defaults.refresh_on_focus),
             prefs.RESIZE_BROWSER_COLUMNS: (
                 self.resize_browser_columns,
                 Defaults.resize_browser_columns,
             ),
+            prefs.SAFE_MODE: (self.safe_mode, Defaults.safe_mode),
             prefs.SPELL_CHECK: (self.check_spelling, Defaults.spellcheck),
             prefs.MOUSE_ZOOM: (self.mouse_zoom, Defaults.mouse_zoom),
+            prefs.NOTIFY_ON_PUSH: (self.notifyonpush, Defaults.notifyonpush),
         })
 
         self.fixed_font.currentFontChanged.connect(self.current_font_changed)
@@ -380,10 +398,10 @@ class AppearanceFormWidget(FormWidget):
         self.add_row(N_('GUI theme'), self.theme)
         self.add_row(N_('Icon theme'), self.icon_theme)
         self.add_row(N_('High DPI'), self.high_dpi)
-        self.add_row(N_('Bold on dark headers instead of italic'), self.bold_headers)
-        self.add_row(N_('Show file counts in Status titles'), self.status_show_totals)
+        self.add_row(N_('Bold on Dark Headers Instead of Italic'), self.bold_headers)
+        self.add_row(N_('Show File Counts in Status Titles'), self.status_show_totals)
         self.add_row(N_('Indent Status paths'), self.status_indent)
-        self.add_row(N_('Use a block cursor in diff editors'), self.block_cursor)
+        self.add_row(N_('Use a Block Cursor in Diff Editors'), self.block_cursor)
 
         self.set_config({
             prefs.BOLD_HEADERS: (self.bold_headers, Defaults.bold_headers),
