@@ -3,6 +3,11 @@ import fnmatch
 import time
 import os
 
+try:
+    import notifypy
+except (ImportError, ModuleNotFoundError):
+    notifypy = None
+
 from qtpy import QtGui
 from qtpy import QtWidgets
 from qtpy.QtCore import Qt
@@ -10,13 +15,16 @@ from qtpy.QtCore import Qt
 from ..i18n import N_
 from ..interaction import Interaction
 from ..models import main
+from ..models import prefs
 from ..models.main import FETCH, FETCH_HEAD, PULL, PUSH
 from ..qtutils import connect_button
 from ..qtutils import get
 from .. import core
+from .. import display
 from .. import git
 from .. import gitcmds
 from .. import icons
+from .. import resources
 from .. import qtutils
 from .. import utils
 from . import defs
@@ -116,6 +124,38 @@ class ActionTask(qtutils.Task):
         return self.model_action(self.remote, **self.kwargs)
 
 
+def _emit_push_notification(
+    context, selected_remotes, pushed_remotes, unpushed_remotes
+):
+    """Emit desktop notification when pushing remotes"""
+    total = len(selected_remotes)
+    count = len(pushed_remotes)
+    scope = {
+        'total': total,
+        'count': count,
+    }
+    title = N_('Pushed %(count)s / %(total)s remotes') % scope
+
+    pushed_message = N_('Pushed: %s') % ', '.join(pushed_remotes)
+    unpushed_message = N_('Not pushed: %s') % ', '.join(unpushed_remotes)
+    success_icon = resources.icon_path('git-cola-ok.svg')
+    error_icon = resources.icon_path('git-cola-error.svg')
+
+    if unpushed_remotes:
+        icon = error_icon
+    else:
+        icon = success_icon
+
+    if pushed_remotes and unpushed_remotes:
+        message = unpushed_message + '\t\t' + pushed_message
+    elif pushed_remotes:
+        message = pushed_message
+    else:
+        message = unpushed_message
+
+    display.notify(context.app_name, title, message, icon)
+
+
 class RemoteActionDialog(standard.Dialog):
     """Interface for performing remote operations"""
 
@@ -547,8 +587,8 @@ class RemoteActionDialog(standard.Dialog):
         displayed = []
         for remote_name in self.model.remotes:
             url = self.model.remote_url(remote_name, self.action)
-            display = '{}\t({})'.format(remote_name, N_('URL: %s') % url)
-            displayed.append(display)
+            display_text = '{}\t({})'.format(remote_name, N_('URL: %s') % url)
+            displayed.append(display_text)
         qtutils.set_items(widget, displayed)
 
     def update_remotes(self, update_command_display=True):
@@ -680,9 +720,25 @@ class RemoteActionDialog(standard.Dialog):
         """Push to all selected remotes"""
         selected_remotes = self.selected_remotes
         all_results = None
+
+        pushed_remotes = []
+        unpushed_remotes = []
+
         for remote in selected_remotes:
             result = self.model.push(remote, *args, **kwargs)
+
+            if result[0] == 0:
+                pushed_remotes.append(remote)
+            else:
+                unpushed_remotes.append(remote)
+
             all_results = combine(result, all_results)
+
+        if prefs.notify_on_push(self.context):
+            _emit_push_notification(
+                self.context, selected_remotes, pushed_remotes, unpushed_remotes
+            )
+
         return all_results
 
     def action_callback(self):
